// ScreenSizer Module
// Jeffrey J Weimer
// SVN History: $Revision: 495 $ on $Date: 2008-01-31 16:32:35 -0500 (Thu, 31 Jan 2008) $
//
// This module creates a root:Package:ScreenSizer folder
// The folder contains eight numerical globals:
//  -> 4 RELATIVE SCREEN SIZES
//   scrwpxl, scrhpxl
//    - RELATIVE screen width and height in pixels (for panels)
//   scrwpnt, scrhpnt
//     - RELATIVE screen width and height in points (for tables and graphs)
//
//  -> 4 PERCENTATE PREFERRED SCREEN REAL ESTATE
//   scrleft, scrtop, scrright, scrbottom
//     - programmer global registers to store preferred screen realestate dimensions (in %)
//     - initialized values are 0, 0, 100, 100
//
//  Use the values in /W=(...) commands for panels, graphs, and tables
//  Alternatively, use built-in commands
//
// EXAMPLES
//
// 	// Initialize (must always do this FIRST!)
//	ScreenSizer#Initialize(0)	// value 0 - do not adjust frame on WinXX systems
//	ScreenSizer#Initialize(1)	// value 1 - adjust frame to fill screen on WinXX systems
//
//	// Set Frame (define preferred screen real estate as precentages of current frame or screen)
//	ScreenSizer#SetFrame(5,5,95,95)
//
//	// Move Front Window (for any window: values as percentages of preferred screen real estate)
//	ScreenSizer#MoveFontWindow(0,0,50,50)
//
//	// Move Command Window (values as percentages of preferred screen real estate)
//	ScreenSizer#MoveCmdWindow(0,65,50,100)
//
//	// Make New Panel (values as %left, %top, width in pixels, height in pixels)
//	ScreenSizer#MakePanel(60,0,120,245,"My New Panel", other="/K=1/N=ControlPanel")
//	  (negative values of %left or %top will offset panel from right or bottom respectively)
//	ScreenSizer#MakePanel(-100,0,120,245,"My New Panel")
//		makes a panel flush right
//
//	// Make New SubPanel (side as interger, other values in pixels!)
//	ScreenSizer#MakeSubPanel(0,0,120,245,"My New SubPanel")
//
// Global values can also be accessed directly
// Create a Panel to Occupy 60% x 40% of the Current Preferred Screen
// Positioned Starting at (left, top ...) by RELATIVE PIXELS
//	NVAR scrwpxl = root:Packages:ScreenSizer:scrwpxl
//	NVAR scrhpxl = root:Packages:ScreenSizer:scrwpxl
//	NVAR scrleft = root:Packages:ScreenSizer:scrleft
//	NVAR scrtop = root:Packages:ScreenSizer:scrtop
//	NewPanel/W=(scrleft*scrwpxl,scrtop*scrhpxl,60*scrwpxl,40*scrhpxl) ...

#pragma rtGlobals=1
#pragma IgorVersion=6.03
#pragma version=1.20

#pragma IndependentModule=ScreenSizer

// Initialize
//   call to the function as ScreenSizer#Initialize(winXX)
//	winXX: 0 - do not change frame size on WinXX systems
//	winXX: 1 - use full frame size on WinXX systems

Function Initialize(winXX)
	variable winXX

	if (DataFolderExists("root:Packages:ScreenSizer")==0)
	
		// initalize from clean start
	
		string cdf = GetDataFolder(1)
		
		NewDataFolder/O/S root:Packages
		NewDataFolder/O/S ScreenSizer
		variable/G scrwpxl, scrhpxl, scrwpnt, scrhpnt
		variable/G scrleft = 0, scrtop = 0, scrright = 100, scrbottom = 100
		SetDataFolder $cdf
	
	endif

	NVAR scrwx = root:Packages:ScreenSizer:scrwpxl
	NVAR scrhx = root:Packages:ScreenSizer:scrhpxl
	NVAR scrwn = root:Packages:ScreenSizer:scrwpnt
	NVAR scrhn = root:Packages:ScreenSizer:scrhpnt

	if (cmpstr(IgorInfo(2),"Macintosh")==0)

		string IgorStuff=""
		variable scr0,scr1,scr2
	
		IgorStuff=IgorInfo(0)
		scr0 = strsearch(IgorStuff,"RECT",0)
		scr1 = strsearch(IgorStuff,",",scr0+9)
		scr2 = strlen(IgorStuff)-2
		
		// values are in RELATIVE PIXELS (for tables and graphs)!!!!
		
		scrwx = str2num(IgorStuff[scr0+9,scr1-1])/100
		scrhx = str2num(IgorStuff[scr1+1,scr2])/100
	else

		// maximize the frame
		
		if (winXX)
			MoveWindow/F 2, 2, 2, 2
		endif
		GetWindow kwFrameInner wsizeDC

		// values are in RELATIVE PIXELS (for panels)!!!!
		
		scrwx = (v_right-v_left)/100
		scrhx = (v_bottom-v_top)/100
	endif
	
	// values in RELATIVE POINTS (for tables and graphs)
	
	scrwn = scrwx*72/ScreenResolution
	scrhn = scrhx*72/ScreenResolution
	
	return 0
End

Function SetFrame(left, top, right, bottom)
	variable left, top, right, bottom
	
	Initialize(0)
	
	NVAR scrleft = root:Packages:ScreenSizer:scrleft
	NVAR scrtop = root:Packages:ScreenSizer:scrtop
	NVAR scrright = root:Packages:ScreenSizer:scrright
	NVAR scrbottom = root:Packages:ScreenSizer:scrbottom
	
	scrleft = left
	scrtop = top
	scrright = right
	scrbottom = bottom
	return 0
end

Function MoveFrontWindow(left, top, right, bottom)
	variable left, top, right, bottom
	
	Initialize(0)
	
	NVAR scrleft = root:Packages:ScreenSizer:scrleft
	NVAR scrtop = root:Packages:ScreenSizer:scrtop
	NVAR scrright = root:Packages:ScreenSizer:scrright
	NVAR scrbottom = root:Packages:ScreenSizer:scrbottom

	NVAR scrwpnt = root:Packages:ScreenSizer:scrwpnt
	NVAR scrhpnt = root:Packages:ScreenSizer:scrhpnt

	left=round(scrwpnt*(scrleft + (scrright - scrleft)*left/100))
	top=round(scrhpnt*(scrtop + (scrbottom-scrtop)*top/100))
	right=round(scrwpnt*(scrleft + (scrright - scrleft)*right/100))
	bottom=round(scrhpnt*(scrtop + (scrbottom-scrtop)*bottom/100))
	
	MoveWindow left,top,right,bottom
	return 0
end

Function MoveCmdWindow(left, top, right, bottom)
	variable left, top, right, bottom
	
	Initialize(0)
	
	NVAR scrleft = root:Packages:ScreenSizer:scrleft
	NVAR scrtop = root:Packages:ScreenSizer:scrtop
	NVAR scrright = root:Packages:ScreenSizer:scrright
	NVAR scrbottom = root:Packages:ScreenSizer:scrbottom

	NVAR scrwpnt = root:Packages:ScreenSizer:scrwpnt
	NVAR scrhpnt = root:Packages:ScreenSizer:scrhpnt

	left=round(scrwpnt*(scrleft + (scrright - scrleft)*left/100))
	top=round(scrhpnt*(scrtop + (scrbottom-scrtop)*top/100))
	right=round(scrwpnt*(scrleft + (scrright - scrleft)*right/100))
	bottom=round(scrhpnt*(scrtop + (scrbottom-scrtop)*bottom/100))
	
	MoveWindow/C left,top,right,bottom
	return 0
end

Function MakePanel(left,top,width,height, strname, [other])
	variable left, top, width, height
	string strname, other
	
	variable right, bottom
	string exeCmd
	
	Initialize(0)
	
	NVAR scrleft = root:Packages:ScreenSizer:scrleft
	NVAR scrtop = root:Packages:ScreenSizer:scrtop
	NVAR scrright = root:Packages:ScreenSizer:scrright
	NVAR scrbottom = root:Packages:ScreenSizer:scrbottom

	NVAR scrwpxl = root:Packages:ScreenSizer:scrwpxl
	NVAR scrhpxl = root:Packages:ScreenSizer:scrhpxl

	if (left>=0)
		left=round(scrwpxl*(scrleft + (scrright - scrleft)*left/100))
	else
		left=round(scrwpxl*(scrleft + (scrright - scrleft)*abs(left)/100) - width)
	endif
	if (top>=0)
		top=round(scrhpxl*(scrtop + (scrbottom-scrtop)*top/100))
	else
		top=round(scrhpxl*(scrtop + (scrbottom-scrtop)*abs(top)/100) - height)
	endif
	right=round(left+width)
	bottom=round(top+height)
	
	if (ParamIsDefault(other))
		sprintf exeCmd "NewPanel/W=(%g,%g,%g,%g)as \"%s\"", left, top, right, bottom, strname
	else
		sprintf exeCmd "NewPanel/W=(%g,%g,%g,%g)%s as \"%s\"", left, top, right, bottom, other, strname
	endif
	execute/Q/Z exeCmd
	return 0
	
end

Function MakeExtPanel(side,offset,width,height, strname, [other])
	variable side, offset, width, height
	string strname, other
	
	variable left, right, top, bottom
	string exeCmd
	
	Initialize(0)
	
	NVAR scrleft = root:Packages:ScreenSizer:scrleft
	NVAR scrtop = root:Packages:ScreenSizer:scrtop
	NVAR scrright = root:Packages:ScreenSizer:scrright
	NVAR scrbottom = root:Packages:ScreenSizer:scrbottom

	NVAR scrwpxl = root:Packages:ScreenSizer:scrwpxl
	NVAR scrhpxl = root:Packages:ScreenSizer:scrhpxl

	switch(side)
		case 0:		
		case 1:
			left = offset
			top = 0
			right = width+offset
			bottom = height
			break
		default:
			left = 0
			top = offset
			right = width
			bottom = height+offset
			break
	endswitch
	
	if (ParamIsDefault(other))
		other = ""
	endif
	other += "/EXT=" + num2str(side)
	sprintf exeCmd "NewPanel/W=(%g,%g,%g,%g)%s as \"%s\"", left, top, right, bottom, other, strname
	execute/Q/Z exeCmd
	return 0
	
end
